@@ -4,6 +4,7 @@ from django.conf.urls.defaults import url, include, patterns
 from django.conf.urls.defaults import handler404, handler500
 from django.contrib import admin
 from django.conf import settings
+from pages.views import PageSitemap, MultiLanguagePageSitemap
 
 
 admin.autodiscover()
@@ -14,29 +15,22 @@ urlpatterns = patterns('',
     (r'^i18n/', include('django.conf.urls.i18n')),
 
     (r'^pages/', include('pages.urls')),
+
+    # this is only used to enable the reverse url to work with documents
+    (r'^pages/(?P<path>.*)', include('pages.testproj.documents.urls')),
+
     (r'^admin/', include(admin.site.urls)),
     # make tests fail if a backend is not present on the system
     #(r'^search/', include('haystack.urls')),
+
+    (r'^sitemap\.xml$', 'django.contrib.sitemaps.views.sitemap',
+        {'sitemaps': {'pages':PageSitemap}}),
+
+    (r'^sitemap2\.xml$', 'django.contrib.sitemaps.views.sitemap',
+        {'sitemaps': {'pages':MultiLanguagePageSitemap}})
+
 )
 
-# An example on how to handle delegated applications:
-
-"""
-if pages_settings.PAGE_USE_LANGUAGE_PREFIX:
-    urlpatterns += patterns('',
-        url(r'^pages/(?P<lang>[-\w]+)/(?P<path>.*)/documents/',
-            include("example.documents.urls")),
-        url(r'^pages/(?P<lang>[-\w]+)/(?P<path>.*)$', details,
-            name='pages-details-by-path')
-    )
-else:
-    urlpatterns += patterns('',
-        url(r'^pages/$', details, name='pages-root'),
-        url(r'^pages/(?P<path>.*)/documents/', include("example.documents.urls")),
-        url(r'^pages/(?P<path>.*)$', details, name='pages-details-by-path')
-    )
-"""
-
 if settings.DEBUG:
     urlpatterns += patterns('',
         # Trick for Django to support static files
